# -*-muttrc-*-
#
# PGP command formats for PGP 6.
#
# $Id$
#

# decode application/pgp
set pgp_decode_command="%?p?PGPPASSFD=0; export PGPPASSFD;? cat %?p?-? %f | pgp6 +compatible   +verbose=0 +batchmode -f"

# verify a pgp/mime signature
set pgp_verify_command="pgp6 +compatible   +verbose=0 +batchmode -t %s %f"

# decrypt a pgp/mime attachment
set pgp_decrypt_command="PGPPASSFD=0; export PGPPASSFD; cat - %f | pgp6 +compatible   +verbose=0 +batchmode -f"

# create a pgp/mime signed attachment
set pgp_sign_command="PGPPASSFD=0; export PGPPASSFD; cat - %f | pgp6 +compatible   +verbose=0 +batchmode -abfst %?a? -u %a?"

# create a pgp/mime encrypted attachment
set pgp_encrypt_only_command="pgp6 +compatible   +verbose=0 +encrypttoself +batchmode -aeft %r < %f"

# create a pgp/mime encrypted and signed attachment
set pgp_encrypt_sign_command="PGPPASSFD=0; export PGPPASSFD; cat - %f | pgp6 +compatible   +verbose=0 +encrypttoself +batchmode +clearsig=off -aefts %?a? -u %a? %r"

# import a key into the public key ring
set pgp_import_command="pgp6 +compatible  -ka %f "

# export a key from the public key ring
set pgp_export_command="pgp6 +compatible  -kxaf  %r"

# verify a key
set pgp_verify_key_command="pgp6 +compatible  -kcc  %r"

# read in the public key ring
set pgp_list_pubring_command="pgpring -5 %r"

# read in the secret key ring
set pgp_list_secring_command="pgpring -s -5 %r"

# create a clearsigned message
set pgp_clearsign_command="PGPPASSFD=0; export PGPPASSFD; cat - %f | pgp6 +compatible   +verbose=0 +batchmode +clearsig -afst %?a? -u %a?"

# fetch keys
set pgp_getkeys_command="pkspxycwrap %r"
