#
# Key bindings similar to those of MUSH
#

# $Id$

bind index . display-message
bind index t display-message
macro index n j\n
bind index + next-entry
bind index j next-entry
bind index J next-entry
bind index - previous-entry
bind index k previous-entry
bind index K previous-entry
bind index { top-page
bind index } bottom-page
bind index f change-folder
bind index \cu sync-mailbox
bind index * flag-message
